// kdelibs4.js of Irish KDE translation

// ------------------------------
// Global dictionary of property getters.
var _propgetters_ = {};

// ------------------------------
// Property getter object contains the following data attributes:
// - callname: the name of the getter call as exposed to PO files
// - values: dictionary of values of this property per phrase
//
function Propgetter (callname)
{
    this.callname = callname;
    this.values = {};

    this.getprop = getprop;

    // Set the PO call.
    Ts.setcall(callname, getprop, this);
}

// Property getter method attached to getter objects.
// If the property is not found, fallback is signalled.
//
function getprop (phrase)
{
    if (phrase in this.values) {
        return this.values[phrase];
    }
    throw Ts.fallback();
}

// ------------------------------
// Set properties of the phrase given by the finalized msgstr in the PO file.
// The arguments to the call are as many keys followed by their value
// as desired (i.e. number of arguments must be even).
//
// The property keys become property getters which can be used to retrive
// the value at a later point. If the getter for a given key already exists,
// the new value is added into its overrides.
//
// The call always signals fallback.
//
function setprops ()
{
    if (arguments.length % 2 != 0)
        throw Error("Property setter given odd number of arguments.");

    for (var i = 0; i < arguments.length; i += 2) {
        var pkey = arguments[i];
        var pval = arguments[i + 1];

        // Either create new, or select existing getter.
        var pgetr;
        if (!_propgetters_[pkey]) {
            // Create new getter for this property.
            pgetr = new Propgetter(pkey);
        }
        else {
            // Get previously defined getter.
            pgetr = _propgetters_[pkey];
        }

        // Associate the property value to finalized msgstr.
        pgetr.values[Ts.msgstrf()] = pval;
    }

    throw Ts.fallback();
}
Ts.setcall("properties", setprops);
